==> satellite-system-2017.2.0-sources.jar: com/xebialabs/deployit/plugin/satellite/PingSatelliteStep.scala <==
package com.xebialabs.deployit.plugin.satellite

import java.io.ObjectInputStream

import akka.actor.ActorSystem
import akka.pattern.ask
import akka.util.Timeout
import com.xebialabs.deployit.engine.tasker.satellite.ActorLocator
import com.xebialabs.deployit.plugin.api.flow.{ExecutionContext, Step, StepExitCode}
import com.xebialabs.satellite.protocol.Paths
import com.xebialabs.xlplatform.satellite.Satellite
import com.xebialabs.xlplatform.settings.CommonSettings

import scala.beans.BeanProperty
import scala.concurrent.duration.FiniteDuration
import scala.concurrent.{Await, Future}

case class PingSatelliteStep(actorLocator: ActorLocator, @BeanProperty description: String, satelliteAddress: String, clock: Clock = Clock())
                            (implicit @transient var satelliteCommunicatorSystem: ActorSystem) extends Step {

  def getOrder: Int = Step.DEFAULT_ORDER

  def execute(ctx: ExecutionContext): StepExitCode = {
    val pingTimeout = CommonSettings(satelliteCommunicatorSystem).satellite.pingTimeout.duration

    implicit val timeout: Timeout = Timeout((pingTimeout * 1.5).asInstanceOf[FiniteDuration])
    implicit val dispatcher = satelliteCommunicatorSystem.dispatcher

    ctx.logOutput(s"Connecting to satellite at $satelliteAddress")

    val pinger = satelliteCommunicatorSystem.actorOf(Pinger.props(ctx, pingTimeout, satelliteAddress, clock))

    val exitCode: Future[StepExitCode] = (pinger ? Pinger.Start(actorLocator.locate(Paths.ping)))
      .mapTo[StepExitCode]
      .recover { case error =>
        ctx.logError(s"Operation failed  (${error.getMessage})")
        StepExitCode.FAIL
      }

    Await.result(exitCode, timeout.duration)
  }

  private def readObject(in: ObjectInputStream): Unit = {
    in.defaultReadObject()
    satelliteCommunicatorSystem = SatelliteCommunicatorSystem.actorSystem
  }
}

object PingSatelliteStep extends SatelliteAddress {

  def apply(satellite: Satellite)(implicit satelliteCommunicatorSystem: ActorSystem): PingSatelliteStep = {
    new PingSatelliteStep(ActorLocator(satellite), s"Ping ${satellite.getName}", satelliteAddress(satellite))
  }
}

==> satellite-system-2017.4.5-sources.jar: com/xebialabs/deployit/plugin/satellite/PingSatelliteStep.scala <==
package com.xebialabs.deployit.plugin.satellite

import java.io.ObjectInputStream

import akka.actor.ActorSystem
import akka.pattern.ask
import akka.util.Timeout
import com.xebialabs.deployit.engine.tasker.satellite.ActorLocator
import com.xebialabs.deployit.plugin.api.flow.{ExecutionContext, Step, StepExitCode}
import com.xebialabs.satellite.protocol.Paths
import com.xebialabs.xlplatform.satellite.Satellite
import com.xebialabs.xlplatform.settings.CommonSettings

import scala.beans.BeanProperty
import scala.concurrent.duration.FiniteDuration
import scala.concurrent.{Await, Future}

case class PingSatelliteStep(actorLocator: ActorLocator, @BeanProperty description: String, satelliteAddress: SatelliteAddress, clock: Clock = Clock())
                            (implicit @transient var satelliteCommunicatorSystem: ActorSystem) extends Step {

  def getOrder: Int = Step.DEFAULT_ORDER

  def execute(ctx: ExecutionContext): StepExitCode = {
    val pingTimeout = CommonSettings(satelliteCommunicatorSystem).satellite.pingTimeout.duration

    implicit val timeout: Timeout = Timeout((pingTimeout * 1.5).asInstanceOf[FiniteDuration])
    implicit val dispatcher = satelliteCommunicatorSystem.dispatcher

    ctx.logOutput(s"Connecting to satellite at $satelliteAddress")

    val pinger = satelliteCommunicatorSystem.actorOf(Pinger.props(ctx, pingTimeout, satelliteAddress, clock))

    val exitCode: Future[StepExitCode] = (pinger ? Pinger.Start(actorLocator.locate(Paths.ping)))
      .mapTo[StepExitCode]
      .recover { case error =>
        ctx.logError(s"Operation failed  (${error.getMessage})")
        StepExitCode.FAIL
      }

    Await.result(exitCode, timeout.duration)
  }

  private def readObject(in: ObjectInputStream): Unit = {
    in.defaultReadObject()
    satelliteCommunicatorSystem = SatelliteCommunicatorSystem.actorSystem
  }
}

object PingSatelliteStep {

  def apply(satellite: Satellite)(implicit satelliteCommunicatorSystem: ActorSystem): PingSatelliteStep = {
    new PingSatelliteStep(ActorLocator(satellite), s"Ping ${satellite.getName}", SatelliteAddress(satellite))
  }
}
